![banner](https://docs.exegol.com/external/banner.png)

Exegol is a comprehensive cybersecurity environment designed by offensive security experts, for fellow hackers, with its community. It solves the common pain points of traditional security distributions by providing a modular and reliable toolkit that's made for the field.

Want to know more about the project? Go to [exegol.com](https://exegol.com)

# Getting started

How to install Exegol: [exegol.com/install](https://exegol.com/install)

The official project documentation details how Exegol is structured. Go to [docs.exegol.com](https://docs.exegol.com/).
